@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 import re
-from ..reg import regularExtrator as pre
+from ..reg import RegularExtrator as pre
 
-class regularExtrator(pre):
+class RegularExtrator(pre):
 
     def __init__(self, text='',data_list = []):
         pre.__init__(self, text, data_list)  
@@ -11,12 +11,13 @@ class regularExtrator(pre):
         
     def clear_list(self,pattern = r'[\s]*'):
         # 去除空格换行符等字符的txt文本列表
-        data_drop = []
-        for item in self.data_list: 
+        data_list = self.flatten(self.data_list)
+        data_list_out = []
+        for item in data_list: 
             txt_drop = re.sub(pattern, '', item)       # 清除换行,制表,空格
-            data_drop.append(txt_drop)
-        self.data_list = data_drop
-        return data_drop 
+            data_list_out.append(txt_drop)
+        self.data_list = data_list_out
+        return self.data_list 
     
     def clear_txt(self,pattern = r'[\s]*'):
         # 去除空格换行符等字符的txt文本列表  
